@@ -15,7 +15,7 @@ use std::sync::{self, Arc};
 use std::time::{Duration, Instant};
 use tracing::{error, info, warn};
 
-use arti_client::{ConnectPrefs, IsolationToken, TorClient};
+use arti_client::{IsolationToken, StreamPrefs, TorClient};
 use tor_rtcompat::{Runtime, TcpListener};
 use tor_socksproto::{SocksAddr, SocksAuth, SocksCmd, SocksRequest};
 
@@ -23,8 +23,8 @@ use anyhow::{anyhow, Context, Result};
 
 /// Find out which kind of address family we can/should use for a
 /// given `SocksRequest`.
-fn stream_preference(req: &SocksRequest, addr: &str) -> ConnectPrefs {
-    let mut prefs = ConnectPrefs::new();
+fn stream_preference(req: &SocksRequest, addr: &str) -> StreamPrefs {
+    let mut prefs = StreamPrefs::new();
     if addr.parse::<Ipv4Addr>().is_ok() {
         // If they asked for an IPv4 address correctly, nothing else will do.
         prefs.ipv4_only();
@@ -188,7 +188,7 @@ where
             // The SOCKS request wants us to connect to a given address.
             // So, launch a connection over Tor.
             let tor_stream = tor_client
-                .connect_with_prefs((addr.clone(), port), prefs)
+                .connect_with_prefs((addr.clone(), port), &prefs)
                 .await;
             let tor_stream = match tor_stream {
                 Ok(s) => s,
@@ -226,7 +226,7 @@ where
         SocksCmd::RESOLVE => {
             // We've been asked to perform a regular hostname lookup.
             // (This is a tor-specific SOCKS extension.)
-            let addrs = tor_client.resolve_with_prefs(&addr, prefs).await?;
+            let addrs = tor_client.resolve_with_prefs(&addr, &prefs).await?;
             if let Some(addr) = addrs.first() {
                 let reply = request.reply(
                     tor_socksproto::SocksStatus::SUCCEEDED,
@@ -247,7 +247,7 @@ where
                     return Err(anyhow!(e));
                 }
             };
-            let hosts = tor_client.resolve_ptr_with_prefs(addr, prefs).await?;
+            let hosts = tor_client.resolve_ptr_with_prefs(addr, &prefs).await?;
             if let Some(host) = hosts.into_iter().next() {
                 let reply = request.reply(
                     tor_socksproto::SocksStatus::SUCCEEDED,
